# Generated by Django 2.2.5 on 2019-09-18 02:53

import django.contrib.postgres.fields
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_dicom.models.fields
import django_dicom.models.validators
import django_extensions.db.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('research', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Image',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('dcm', models.FileField(max_length=250, upload_to='dicom', validators=[django_dicom.models.validators.validate_file_extension])),
                ('uid', models.CharField(max_length=64, unique=True, validators=[django.core.validators.RegexValidator('^\\d+(\\.\\d+)*$', code='invalid_uid', message='Digits and dots only!')], verbose_name='Image UID')),
                ('number', models.IntegerField(verbose_name='Image Number')),
                ('date', models.DateField(blank=True, null=True)),
                ('time', models.TimeField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Patient',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('uid', models.CharField(max_length=64, unique=True, verbose_name='Patient UID')),
                ('date_of_birth', models.DateField(blank=True, null=True)),
                ('sex', models.CharField(blank=True, choices=[('M', 'Male'), ('F', 'Female'), ('O', 'Other')], max_length=1, null=True)),
                ('given_name', models.CharField(blank=True, max_length=64, null=True)),
                ('family_name', models.CharField(blank=True, max_length=64, null=True)),
                ('middle_name', models.CharField(blank=True, max_length=64, null=True)),
                ('name_prefix', models.CharField(blank=True, max_length=64, null=True)),
                ('name_suffix', models.CharField(blank=True, max_length=64, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Series',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('uid', models.CharField(help_text='Unique identifier of the series', max_length=64, unique=True, validators=[django.core.validators.RegexValidator('^\\d+(\\.\\d+)*$', code='invalid_uid', message='Digits and dots only!')], verbose_name='Series UID')),
                ('number', models.PositiveIntegerField(blank=True, help_text='A number that identifies this series within a given session', null=True, verbose_name='Series Number')),
                ('description', models.CharField(blank=True, help_text='Description of the series', max_length=64, null=True, verbose_name='Series Description')),
                ('date', models.DateField(blank=True, help_text='Date the series started', null=True)),
                ('time', models.TimeField(blank=True, help_text='Time the series started', null=True)),
                ('echo_time', models.FloatField(blank=True, help_text='Time in ms between the middle of the excitation pulse and the peak of the echo produced', null=True, validators=[django.core.validators.MinValueValidator(0)])),
                ('echo_train_length', models.PositiveIntegerField(blank=True, help_text='Number of lines in k-space acquired per excitation per image.', null=True)),
                ('inversion_time', models.FloatField(blank=True, help_text='Time in milliseconds after the middle of inverting RF pulse to middle of excitation pulse to detect the amount of longitudinal magnetization', null=True, validators=[django.core.validators.MinValueValidator(0)])),
                ('repetition_time', models.FloatField(blank=True, help_text='The period of time in milliseconds between the beginning of a pulse sequence and the beginning of the succeeding pulse sequence.', null=True, validators=[django.core.validators.MinValueValidator(0)])),
                ('scanning_sequence', django_dicom.models.fields.ChoiceArrayField(base_field=models.CharField(choices=[('SE', 'Spin Echo'), ('IR', 'Inversion Recovery'), ('GR', 'Gradient Recalled'), ('EP', 'Echo Planar'), ('RM', 'Research Mode')], max_length=2), help_text='Description of the type of data taken', size=5)),
                ('sequence_variant', django_dicom.models.fields.ChoiceArrayField(base_field=models.CharField(choices=[('SK', 'Segmented k-Space'), ('MTC', 'Magnetization Transfer Contrast'), ('SS', 'Steady State'), ('TRSS', 'Time Reversed Steady State'), ('SP', 'Spoiled'), ('MP', 'MAG Prepared'), ('OSP', 'Oversampling Phase'), ('NONE', 'None')], max_length=4), help_text='Variant of the scanning sequence', size=6)),
                ('pixel_spacing', django.contrib.postgres.fields.ArrayField(base_field=models.FloatField(validators=[django.core.validators.MinValueValidator(0)]), help_text='Physical distance in the patient between the center of each pixel, specified by a numeric pair: adjacent row spacing (delimiter) adjacent column spacing in mm', size=2)),
                ('slice_thickness', models.FloatField(blank=True, help_text='Nominal slice thickness, in millimeters.', null=True, validators=[django.core.validators.MinValueValidator(0)])),
                ('manufacturer', models.CharField(blank=True, help_text='Manufacturer of the equipment that produced the composite instances', max_length=64, null=True)),
                ('manufacturer_model_name', models.CharField(blank=True, help_text="Manufacturer's model name of the equipment that produced the composite instances", max_length=64, null=True)),
                ('magnetic_field_strength', models.FloatField(blank=True, help_text='Nominal field strength of MR magnet, in Tesla', null=True, validators=[django.core.validators.MinValueValidator(0)])),
                ('device_serial_number', models.CharField(blank=True, help_text="Manufacturer's serial number of the equipment that produced the Composite Instances", max_length=64, null=True)),
                ('body_part_examined', models.CharField(blank=True, help_text='Text description of the part of the body examined', max_length=16, null=True)),
                ('patient_position', models.CharField(blank=True, choices=[('HFP', 'Head First-Prone'), ('HFS', 'Head First-Supine'), ('HFDR', 'Head First-Decubitus Right'), ('HFDL', 'Head First-Decubitus Left'), ('FFDR', 'Feet First-Decubitus Right'), ('FFDL', 'Feet First-Decubitus Left'), ('FFP', 'Feet First-Prone'), ('FFS', 'Feet First-Supine'), ('LFP', 'Left First-Prone'), ('LFS', 'Left First-Supine'), ('RFP', 'Right First-Prone'), ('RFS', 'Right First-Supine'), ('AFDR', 'Anterior First-Decubitus Right'), ('AFDL', 'Anterior First-Decubitus Left'), ('PFDR', 'Posterior First-Decubitus Right'), ('PFDL', 'Posterior First-Decubitus Left')], help_text='Patient position descriptor relative to the equipment', max_length=4, null=True)),
                ('modality', models.CharField(choices=[('AR', 'Autorefraction'), ('ASMT', 'Content Assessment Results'), ('AU', 'Audio'), ('BDUS', 'Bone Densitometry (ultrasound)'), ('BMD', 'Bone Densitometry (X-Ray)'), ('BI', 'Biomagnetic imaging'), ('CR', 'Computed Radiography'), ('CT', 'Computed Tomography'), ('CTPROTOCOL', 'CT Protocol (Performed)'), ('DG', 'Diaphanography'), ('DOC', 'Document'), ('DX', 'Digital Radiography'), ('ECG', 'Electrocardiography'), ('EPS', 'Cardiac Electrophysiology'), ('EDS', 'Endoscopy'), ('FID', 'Fiducials'), ('GM', 'General Microscopy'), ('HC', 'Hard Copy'), ('HD', 'Hemodynamic Waveform'), ('IO', 'Intra-Oral Radiography'), ('IOL', 'Intraocular Lens Data'), ('IVOCT', 'Intravascular Optical Coherence Tomography'), ('IVUS', 'Intravascular Ultrasound'), ('KER', 'Keratometry'), ('KO', 'Key Object Selection'), ('LEN', 'Lensometry'), ('LS', 'Laser surface scan'), ('MG', 'Mammography'), ('MR', 'Magnetic Resonance'), ('M3D', 'Model for 3D Manufacturing'), ('NM', 'Nuclear Medicine'), ('OAM', 'Ophthalmic Axial Measurements'), ('OCT', 'Optical Coherence Tomography (non-Ophthalmic)'), ('OP', 'Ophthalmic Photography'), ('OPM', 'Ophthalmic Mapping'), ('OPT', 'Ophthalmic Tomography'), ('OPTBSV', 'Ophthalmic Tomography B-scan Volume Analysis'), ('OPTENF', 'Ophthalmic Tomography En Face'), ('OPV', 'Ophthalmic Visual Field'), ('OSS', 'Optical Surface Scan'), ('OT', 'Other'), ('PLAN', 'Plan'), ('PR', 'Presentation State'), ('PT', 'Positron emission tomography (PET)'), ('PX', 'Panoramic X-Ray'), ('REG', 'Registration'), ('RESP', 'Respiratory Waveform'), ('RF', 'Radio Fluoroscopy'), ('RG', 'Radiographic imaging (conventional film/screen)'), ('RTDOSE', 'Radiotherapy Dose'), ('RTIMAGE', 'Radiotherapy Image'), ('RTPLAN', 'Radiotherapy Plan'), ('RTRECORD', 'RT Treatment Record'), ('RTSTRUCT', 'Radiotherapy Structure Set'), ('RWV', 'Real World Value Map'), ('SEG', 'Segmentation'), ('SM', 'Slide Microscopy'), ('SMR', 'Stereometric Relationship'), ('SR', 'SR Document'), ('SRF', 'Subjective Refraction'), ('STAIN', 'Automated Slide Stainer'), ('TG', 'Thermography'), ('US', 'Ultrasound'), ('VA', 'Visual Acuity'), ('XA', 'X-Ray Angiography'), ('XC', 'External-camera Photography')], help_text='Type of equipment that originally acquired the data used to create the images in this series', max_length=10)),
                ('institution_name', models.CharField(blank=True, help_text='Institution where the equipment that produced the Composite Instances is located', max_length=64, null=True)),
                ('operators_name', models.CharField(blank=True, help_text='Name(s) of the operator(s) supporting the Series.', max_length=64, null=True)),
                ('protocol_name', models.CharField(blank=True, help_text='User-defined description of the conditions under which the series was performed', max_length=64, null=True)),
                ('flip_angle', models.FloatField(blank=True, help_text='Steady state angle in degrees to which the magnetic vector is flipped from the magnetic vector of the primary field.', null=True)),
                ('mr_acquisition_type', models.CharField(blank=True, choices=[('2D', '2D'), ('3D', '3D')], help_text='Identification of data encoding scheme', max_length=2, null=True)),
            ],
            options={
                'verbose_name_plural': 'Series',
                'ordering': ('number',),
            },
        ),
        migrations.CreateModel(
            name='Study',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('uid', models.CharField(max_length=64, unique=True, validators=[django.core.validators.RegexValidator('^\\d+(\\.\\d+)*$', code='invalid_uid', message='Digits and dots only!')], verbose_name='Study UID')),
                ('description', models.CharField(blank=True, max_length=64, null=True)),
                ('date', models.DateField(blank=True, null=True)),
                ('time', models.TimeField(blank=True, null=True)),
            ],
            options={
                'verbose_name_plural': 'Studies',
            },
        ),
        migrations.AddIndex(
            model_name='study',
            index=models.Index(fields=['uid'], name='django_dico_uid_5f639a_idx'),
        ),
        migrations.AddField(
            model_name='series',
            name='patient',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, to='django_dicom.Patient'),
        ),
        migrations.AddField(
            model_name='series',
            name='study',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='django_dicom.Study'),
        ),
        migrations.AddField(
            model_name='patient',
            name='subject',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.PROTECT, related_name='dicom_patient_set', to='research.Subject'),
        ),
        migrations.AddField(
            model_name='image',
            name='series',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, to='django_dicom.Series'),
        ),
        migrations.AddIndex(
            model_name='series',
            index=models.Index(fields=['uid'], name='django_dico_uid_95ea17_idx'),
        ),
        migrations.AddIndex(
            model_name='series',
            index=models.Index(fields=['date', 'time'], name='django_dico_date_c6f151_idx'),
        ),
        migrations.AddIndex(
            model_name='patient',
            index=models.Index(fields=['uid'], name='django_dico_uid_285d78_idx'),
        ),
        migrations.AddIndex(
            model_name='patient',
            index=models.Index(fields=['date_of_birth'], name='django_dico_date_of_49f161_idx'),
        ),
        migrations.AddIndex(
            model_name='image',
            index=models.Index(fields=['uid'], name='django_dico_uid_d005ca_idx'),
        ),
        migrations.AddIndex(
            model_name='image',
            index=models.Index(fields=['date', 'time'], name='django_dico_date_437885_idx'),
        ),
    ]
